Module cli

Module cli 

Structs

BuildArgs
Cli
CompletionsArgs
DbDropArgs
DbResetArgs
DocsArgs
ExecArgs
FmtArgs
LintArgs
PassthroughArgs
PublishArgs
ReleaseArgs
RunArgs
RunFileArgs
TestArgs
UniversalFlags

Enums

Command
ConfigCommand
DbCommand
DepCommand
ToolCommand

Functions

collect_remaining_args
Collects the passthrough/trailing args from any command variant.
collect_universal_flags
Extracts known universal flags from a command variant.
command_parts
Returns the dot-notation command name and an optional reference to the passthrough args vec for the given command variant.
parse_command_name
Returns a dot-notation name for the given command variant.