command_parts

Function command_parts 

pub fn command_parts(cmd: &Command) -> (&'static str, Option<&Vec<String>>)
Returns the dot-notation command name and an optional reference to the passthrough args vec for the given command variant.