Module executor

Module executor 

Structs

ResolveContext
Context for command resolution.

Functions

execute_command
Execute a command string, replacing the current process on Unix.
expand_template
Expand template placeholders in a command string.
resolve_alias
Resolve an alias from config to a command string.
resolve_command
Resolve a command to a fully expanded command string ready for execution.
spawn_command
Execute a command and return its exit code (non-exec variant for testing).
split_command
Split a command string into parts using shell-words.